SystemOrganization addCategory: #'Ring-Tests-Kernel'!

TestCase subclass: #RGClassDefinitionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Ring-Tests-Kernel'!

!RGClassDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 16:43'!
testAddingMethods
	| newMethod newClass |
	
	newClass:= RGFactory current createClassNamed: #OrderedCollection.
	newMethod:= (RGFactory current createMethodNamed: #add: parent: newClass)
					protocol: 'adding';
					sourceCode: 'add: newObject
									^self addLast: newObject'.
	
	self assert: (newMethod isMetaSide not).
	self assert: (newClass hasMethods not).

	newClass addMethod: newMethod.
	newClass addSelector: #size 
			   classified: 'accessing' 
			   sourced: 'fakeMethod
							^lastIndex - firstIndex + 1'.
	
	self assert: (newClass hasMethods).
	self assert: (newClass selectors = #(add: size)).
	self assert: (newClass includesSelector: #add:).
	self assert: ((newClass methodNamed: #add:) = newMethod).
	self assert: (newClass methods size = 2).
	self assert: (newClass selectors size = 2).
	self assert: (newClass allSelectors size = 2).  "no hierarchy"

	newMethod:= newClass methodNamed: #size.
	self assert: (newMethod parent = newClass).
	
	self assert: ((newClass compiledMethodNamed: #size) notNil).
	self assert: ((newClass compiledMethodNamed: #fakeMethod) isNil)! !

!RGClassDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 5/12/2011 19:31'!
testAsClassDefinition
	| newClass |

	newClass:= OrderedCollection asRingDefinition.
	
	self assert: (newClass isRingObject).
	self assert: (newClass isClass).  
	self assert: (newClass name == #OrderedCollection).  
	self assert: (newClass category notNil).
	self assert: (newClass superclassName notNil).
	
	self assert: (newClass theMetaClass isRingObject).
	self assert: (newClass theMetaClass isClass).! !

!RGClassDefinitionTest methodsFor: 'testing' stamp: 'StephaneDucasse 7/19/2011 10:41'!
testAsClassDefinition2

	| newClass |
	newClass:= Trait asRingDefinition.
	
	self assert: (newClass isRingObject).
	self assert: (newClass isClass).  
	self assert: (newClass name == #Trait).  
	self assert: (newClass category notNil).
	self assert: (newClass superclassName notNil).
	self assert: (newClass  traitCompositionSource = 'TBehaviorCategorization').
	
	self assert: (newClass theMetaClass isRingObject).
	self assert: (newClass theMetaClass isClass).
	self assert: (newClass theMetaClass traitCompositionSource = 'TBehaviorCategorization classTrait').
	! !

!RGClassDefinitionTest methodsFor: 'testing' stamp: 'StephaneDucasse 7/19/2011 10:43'!
testAsClassDefinitionSourceDefinition

	| newClass |
	newClass:= Trait asRingDefinition.
	self assert: (newClass definitionSource =  'TraitDescription subclass: #Trait
	uses: TBehaviorCategorization
	instanceVariableNames: ''name environment classTrait category''
	classVariableNames: ''''
	poolDictionaries: ''''
	category: ''Traits-Kernel''').
	
	self assert: (newClass theMetaClass definitionSource =  'Trait class
	uses: TBehaviorCategorization classTrait
	instanceVariableNames: ''''').
	! !

!RGClassDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 8/10/2011 11:42'!
testClassEquality
	| newClass |
	
	self assert: OrderedCollection asRingDefinition = OrderedCollection asRingDefinition.
	
	newClass := (OrderedCollection asRingDefinition)
		category: #Kernel.
	self assert: (OrderedCollection asRingDefinition = newClass) ! !

!RGClassDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 16:10'!
testExistingClass
	| newClass metaClass |
	
	newClass:= RGFactory current createClassNamed: #OrderedCollection.
	self assert: (newClass isClass).
	self assert: (newClass isDefined).
	self assert: (newClass realClass = OrderedCollection).
	self assert: (newClass isMeta not).
	
	newClass withMetaclass.
	self assert: (newClass hasMetaclass).
	metaClass:= newClass theMetaClass.
	self assert: (metaClass isMeta).
	self assert: (metaClass name = 'OrderedCollection class').
	self assert: (metaClass theNonMetaClass = newClass).
	self assert: (metaClass realClass = OrderedCollection class).! !

!RGClassDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 16:11'!
testNonExistingClass
	| newClass |
	
	newClass:= RGFactory current createClassNamed: #Connection.
	self assert: (newClass isClass).
	self assert: (newClass instanceVariables isEmpty).
	self assert: (newClass classVariables isEmpty).
	self assert: (newClass poolDictionaries isEmpty).
	self assert: (newClass hasMetaclass not).
	self assert: (newClass hasComment not).
	self assert: (newClass hasStamp not).
	self assert: (newClass parent = Smalltalk globals).
	self assert: (newClass package isNil).
	self assert: (newClass category isNil).
	self assert: (newClass hasMethods not).
	self assert: (newClass hasSuperclass not).
	self assert: (newClass hasTraitComposition not).
	self assert: (newClass isDefined not).
	self assert: (newClass hasProtocols not).
	
	! !

!RGClassDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 16:44'!
testRemovingMethods
	| newMethod newClass |
	
	newClass:= RGFactory current createClassNamed: #OrderedCollection.
	newMethod:= (RGFactory current createMethodNamed: #add: parent: newClass)
					protocol: 'adding';
					sourceCode: 'add: newObject
									^self addLast: newObject'.
	self assert: (newClass hasMethods not).

	newClass addMethod: newMethod.
	newClass addSelector: #size 
			   classified: 'accessing' 
			   sourced: 'size
							^ lastIndex - firstIndex + 1'.
	
	self assert: (newClass selectors = #(add: size)).
	newClass removeSelector: #join:.
	self assert: (newClass selectors = #(add: size)).
	newClass removeMethod: newMethod.
	self assert: ((newClass includesSelector: #add:) not).
	newClass removeSelector: #size.
	self assert: (newClass hasMethods not).! !

!RGClassDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 16:11'!
testWithCategory
	| newClass |
	
	newClass:= (RGFactory current createClassNamed: #Object)
						category: 'Kernel-Objects';
						yourself.

	self assert: (newClass package isNil).
	self assert: (newClass category = 'Kernel-Objects').! !

!RGClassDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 16:11'!
testWithClassInstanceVariables
	| newClass metaClass classInstVar |
	
	newClass:= RGFactory current createClassNamed: #HashTableSizes.
	newClass withMetaclass.
	metaClass:= newClass theMetaClass.
	metaClass addInstanceVariables: #(sizes).
	
	self assert: (metaClass instanceVariables size = 1).
	self assert: (metaClass instVarNames size = 1).
	self assert: (metaClass allInstVarNames size = 1).
	
	classInstVar:= metaClass instVarNamed: #sizes.
	self assert: (classInstVar notNil).
	self assert: (classInstVar parent = metaClass).
	self assert: (classInstVar isClassInstanceVariable).
	self assert: (classInstVar isVariable).
	self assert: (classInstVar parentName = metaClass name).
	self assert: (classInstVar realClass = HashTableSizes class).
	
	metaClass removeInstVarNamed: #sizes.
	self assert: (metaClass instanceVariables isEmpty).
	self assert: ((metaClass instVarNamed: #sizes) isNil).
	! !

!RGClassDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 16:11'!
testWithClassVariables
	| newClass classVar |
	
	newClass:= (RGFactory current createClassNamed: #Object)
						addClassVariables: #(DependentsFields);
						addClassVarNamed: #FakeVariable;
						yourself.

	self assert: (newClass classVariables size = 2).
	self assert: (newClass classVarNames size = 2).
	self assert: (newClass allClassVarNames size = 2).  "no hierarchy"
	
	classVar:= newClass classVarNamed: #DependentsFields.
	self assert: (classVar notNil).
	self assert: (classVar isClassVariable).
	self assert: (classVar isVariable).
	self assert: (classVar parent = newClass).
	self assert: (classVar parentName == newClass name).
	self assert: (classVar realClass = Object).
	
	newClass withMetaclass.
	self assert: (newClass theMetaClass allClassVarNames size = 2).
	
	newClass removeClassVarNamed: #DependentsFields.
	self assert: (newClass classVariables size = 1).! !

!RGClassDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 5/12/2011 19:34'!
testWithComment
	| newClass newComment |
	
	newClass:= RGFactory current createClassNamed: #Object.
	newComment:= RGFactory current createComment
						parent: newClass;
						content: 'This is a comment for test';
						stamp: 'VeronicaUquillas 3/22/2011 14:51';
						yourself.
	newClass comment: newComment.

	self assert: (newClass hasComment).
	self assert: (newClass hasStamp).
	self assert: (newClass = newComment parent).
	self assert: (newComment content = 'This is a comment for test').
	self assert: (newComment authorAlias = 'VeronicaUquillas').
	self assert: (newComment timeStamp = '3/22/2011 14:51' asDateAndTime).
	
	newClass comment: nil.
	self assert: (newClass hasComment not).
	
	newClass comment:  'This is a comment for test';
			  stamp: 'VeronicaUquillas 3/22/2011 14:51'.
	
	self assert: (newClass comment isRingObject).
! !

!RGClassDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 5/9/2011 16:19'!
testWithDefaultNamespace
	| newClass |
	
	newClass:= RGFactory current createClassNamed: #Object.

	self assert: (newClass parent = Smalltalk globals).
	self assert: (newClass realClass = Object).! !

!RGClassDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 16:12'!
testWithInstanceVariables
	| newClass instVar |
	
	newClass:= RGFactory current createClassNamed: #OrderedCollection.
	newClass addInstanceVariables: #(array firstIndex).
	newClass addInstVarNamed: #lastIndex.
	
	self assert: (newClass instanceVariables size = 3).
	self assert: (newClass instVarNames size = 3).
	self assert: (newClass allInstVarNames size = 3).
	
	instVar:= newClass instVarNamed: #firstIndex.
	self assert: (instVar notNil).
	self assert: (instVar parent = newClass).
	self assert: (instVar isInstanceVariable).
	self assert: (instVar isVariable).
	self assert: (instVar parentName == newClass name).
	self assert: (instVar realClass = OrderedCollection).
	
	newClass removeInstVarNamed: #array.
	self assert: (newClass instanceVariables size = 2).
	self assert: ((newClass instVarNamed: #array) isNil).
	! !

!RGClassDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 5/23/2011 11:34'!
testWithPoolDictionaries
	| newClass poolVar |
	
	newClass:= (RGFactory current createClassNamed: #Text)
						addPoolDictNamed: #TextConstants;
						yourself.

	self assert: (newClass poolDictionaries size = 1).
	self assert: (newClass poolDictNames size = 1).
	self assert: (newClass allPoolDictionaries size = 1).  "no hierarchy"
	self assert: (newClass allPoolDictNames size = 1).
	
	poolVar:= newClass poolDictNamed: #TextConstants.
	self assert: (poolVar notNil).
	self assert: (poolVar isPoolVariable).
	self assert: (poolVar isVariable).
	self assert: (poolVar parent = newClass).
	self assert: (poolVar parentName == newClass name).
	self assert: (poolVar realClass = Text).
	
	newClass withMetaclass.
	self assert: (newClass theMetaClass allPoolDictNames size = 1).
	
	newClass removePoolDictNamed: #TextConstants.
	self assert: (newClass poolDictionaries isEmpty).! !

!RGClassDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 16:44'!
testWithProtocols
	| newMethod newClass |
	
	newClass:= RGFactory current createClassNamed: #OrderedCollection.
	newMethod:= (RGFactory current createMethodNamed: #add: parent: newClass)
					protocol: 'adding'; 
					sourceCode: 'add: newObject
									^self addLast: newObject'.
	
	newClass addMethod: newMethod.
	newClass addProtocol: 'accessing'.
	
	self assert: (newClass hasProtocols).
	self assert: (newClass protocols size = 2).
	self assert: (newClass includesProtocol: 'accessing').
	self assert: ((newClass methodsInProtocol: 'adding') size = 1).
	self assert: ((newClass methodsInProtocol: 'accessing') isEmpty)! !

!RGClassDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 5/12/2011 19:16'!
testWithSuperclass
	| newClass supClass classVar |
	
	supClass:= (RGFactory current createClassNamed: #Object)
						superclassName: #ProtoObject;
						yourself.

	self assert: (supClass hasSuperclass not).
	self assert: (supClass superclassName == #ProtoObject).   "kept as annotation"
	self assert: (supClass annotations size = 1).
	
	newClass:= RGFactory current createClassNamed: #OrderedCollection subclassOf:  supClass.
	self assert: (newClass superclass = supClass).
	self assert: (newClass superclassName == #Object).
	self assert: (newClass withAllSuperclasses size = 2).
	self assert: (newClass allSuperclasses size = 1).
	
	self assert: (supClass subclasses size = 1).
	self assert: (supClass withAllSubclasses size = 2).
	self assert: (supClass allSubclasses size = 1).! !

TestCase subclass: #RGCommentDefinitionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Ring-Tests-Kernel'!

!RGCommentDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 16:28'!
testCommentWithoutAuthor
	| newComment |
	
	newComment:= RGFactory current createComment
						content: 'This is a comment for test';
						stamp: '3/22/2011 14:51';
						yourself.
	
	self assert: (newComment hasAuthorAlias not).! !

!RGCommentDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 5/12/2011 20:00'!
testNewComment
	| newComment |
	
	newComment:= RGFactory current createComment
						content: 'This is a comment for test';
						stamp: 'VeronicaUquillas 3/22/2011 14:51';
						yourself.
	
	self assert: (newComment isComment).
	self assert: (newComment hasStamp).
	self assert: (newComment hasAuthorAlias).
	self assert: (newComment timeStamp notNil).
	
	self assert: (newComment authorAlias = 'VeronicaUquillas').
	self assert: (newComment timeStamp = '3/22/2011 14:51' asDateAndTime).
	self assert: (newComment parent = nil).
	self assert: (newComment environment = Smalltalk globals).! !

TestCase subclass: #RGGlobalDefinitionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Ring-Tests-Kernel'!

!RGGlobalDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 8/10/2011 11:42'!
testEquality
	| global1 global2 |
	
	global1 := RGFactory current createGlobalVariableNamed: #Transcript..
	global2 := RGFactory current createGlobalVariableNamed: #Transcript.
	self assert: global1 = global2.
	
	global2 := RGFactory current createGlobalVariableNamed: #Transcript2.
	self deny: global1 = global2.! !

!RGGlobalDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 16:18'!
testGlobalVariableDefinition
	| global newClass |
	
	global:= RGFactory current createGlobalVariableNamed: #Transcript.
	
	self assert: (global isGlobalVariable).
	self assert: (global parent = Smalltalk globals).! !

!RGGlobalDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 8/2/2011 14:13'!
testPoolDefinition
	| pool newClass |
	
	pool:= RGFactory current createSharedPoolNamed: #TextConstants.
	self assert: (pool isPool).
	self assert: (pool users isEmpty).
	self assert: (pool parent = Smalltalk globals).
	
	newClass:= RGFactory current createClassNamed: #OrderedCollection.
	pool addUser: newClass.
	self assert: (pool users size = 1).
	self assert: (pool includesUser: newClass).
	self assert: ((newClass poolDictNamed: #TextConstants) isPoolVariable).
	
	pool:= RGFactory current createClassNamed: #TextConstants.
	pool superclassName: #SharedPool.
	self assert: (pool isPool).
	self assert: (pool users isEmpty).! !

TestCase subclass: #RGMethodDefinitionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Ring-Tests-Kernel'!

!RGMethodDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 5/12/2011 19:29'!
testAsMethodDefinition
	| newMethod |

	newMethod:= (OrderedCollection >> #size) asRingDefinition.
	
	self assert: (newMethod isRingObject).
	self assert: (newMethod isMethod).  
	self assert: (newMethod selector == #size).  
	self assert: (newMethod protocol notNil).
	self assert: (newMethod stamp notNil).! !

!RGMethodDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 8/2/2011 17:05'!
testAsMethodDefinition2
	"self debug: #testAsMethodDefinition2"
	
	| newMethod |
	newMethod := (Object >> #printOn:) asRingDefinition.
	self assert: newMethod asStringOrText asString = 'Object>>printOn: {printing} '.
	self assert:  newMethod protocol = 'printing'.
	
	newMethod := (TCloneTest>>#testCopyEmpty) asRingDefinition.
	self assert:  newMethod protocol = 'tests - copy - clone'.

	newMethod := (ArrayTest>>#testCopyEmpty) asRingDefinition.
	"The sourcePointer of this method does not return a protocol... This is a problem with methods of a trait, in this example ArrayTest uses TCloneTest"
	self assert:  newMethod protocol = 'unfound protocol'.
	
	! !

!RGMethodDefinitionTest methodsFor: 'testing' stamp: 'StephaneDucasse 8/12/2011 14:48'!
testDifferentObjectButSameMethodInSet
	"self debug: #testDifferentObjectButSameMethodInSet"

	| s rgmethod rgmethod2 |
	s := Set new.
	rgmethod := (OrderedCollection>>#size) asRingDefinition.
	s add: rgmethod. 
	rgmethod2 := (OrderedCollection>>#size) asRingDefinition.
	s add: rgmethod2.
	
	self assert: (s size = 1).
	self assert: (s includes: rgmethod).
	self assert: (s includes: rgmethod2).

! !

!RGMethodDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 16:38'!
testExistingMethodWithClass
	| newMethod newClass |
	
	newClass:= RGFactory current createClassNamed: #OrderedCollection.
	newMethod:= (RGFactory current createMethodNamed: #add: parent: newClass)
					protocol: 'adding';
					sourceCode: 'add: newObject
									^self addLast: newObject'.
									
	self assert: (newMethod isMethod).
	self assert: (newMethod selector == #add:).
	self assert: (newMethod isMetaSide not).
	
	self assert: (newMethod parent = newClass).
	self assert: (newMethod parentName == newClass name).
	
	self assert: (newMethod parent parent == Smalltalk globals).
	self assert: (newMethod realClass = OrderedCollection).
	self assert: (newMethod compiledMethod = (OrderedCollection compiledMethodAt: #add:)).! !

!RGMethodDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 7/22/2011 10:57'!
testExistingMethodWithPointer
	| newMethod |
	
	newMethod:= RGFactory current createMethodNamed: #size realParent: OrderedCollection.
									
	self assert: (newMethod parent isNil).
	self assert: (newMethod parentName == #OrderedCollection).
	self assert: (newMethod sourceCode notNil).
	self assert: (newMethod protocol notNil).
	self assert: (newMethod stamp notNil).
	self assert: (newMethod isExtension not)! !

!RGMethodDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 16:38'!
testExistingMethodWithoutClass
	"its parent class is not assigned only its name"
	| newMethod |
	
	newMethod:= (RGFactory current createMethodNamed: #add:)
					parentName: #OrderedCollection;
					selector: #add:; 
					isMetaSide: false;
					protocol: 'adding'; 
					sourceCode: 'add: newObject
									^self addLast: newObject'.
	
	self assert: (newMethod isMethod).
	self assert: (newMethod selector == #add:).
	self assert: (newMethod isMetaSide not).
	self assert: (newMethod protocol = #adding).
	self assert: (newMethod fullName = 'OrderedCollection>>add:').
	self assert: (newMethod sourceCode = 'add: newObject
									^self addLast: newObject').
	self assert: (newMethod hasStamp not).
	self assert: (newMethod parent isNil).
	self assert: (newMethod parentName == #OrderedCollection).
	
	self assert: (newMethod environment == Smalltalk globals).
	self assert: (newMethod realClass = OrderedCollection).
	self assert: (newMethod compiledMethod = (OrderedCollection compiledMethodAt: #add:))! !

!RGMethodDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 8/2/2011 11:46'!
testExtensionMethod
	| newMethod newClass newPackage newPackageExt |

	newMethod:= (RGFactory current createMethodNamed: #+)
					isExtension: true.
	self assert: (newMethod protocol isNil).
	self assert: (newMethod isExtension).

	newMethod:= (Collection >> #+) asRingDefinition.	
	self assert: (newMethod isMethod).  
	self assert: (newMethod protocol = '*Collections-arithmetic').
	self assert: (newMethod isExtension).
	
	newPackage := RGFactory current createPackageNamed: #Package.
	newPackageExt := RGFactory current createPackageNamed: #PackageExtensions.
	newClass := RGFactory current createClassNamed: #Class.
	newMethod := RGFactory current createMethodNamed: #foo parent: newClass.
	newPackage addClass: newClass.
	newMethod package: newPackageExt.
	self assert: (newMethod isExtension).! !

!RGMethodDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 8/10/2011 11:42'!
testMethodEquality

	| newMethod newClass |
	self assert: (OrderedCollection>>#size) asRingDefinition = (OrderedCollection>>#size) asRingDefinition.
	
	newMethod := ((OrderedCollection>>#size) asRingDefinition)
					sourceCode: 'size
						^0'.
	self assert: ((OrderedCollection>>#size) asRingDefinition = newMethod).
	
	newClass:= RGFactory current createClassNamed: #OrderedCollection.
	newMethod:= (RGFactory current createMethodNamed: #size parent: newClass).
	self assert: ((OrderedCollection>>#size) asRingDefinition = newMethod).
	
	newMethod:= (RGFactory current createMethodNamed: #size parent: (SortedCollection asRingDefinition)).
	self deny: ((OrderedCollection>>#size) asRingDefinition = newMethod).! !

!RGMethodDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 17:11'!
testNonExistingMethodWithClass
	"method does not exist in OrderedCollection"
	| newMethod newClass |
	
	newClass:= RGFactory current createClassNamed: #OrderedCollection.
	newClass withMetaclass.
	
	newMethod:= RGFactory current createMethodNamed: #foo parent: newClass theMetaClass.
	newMethod sourceCode: 'foo
									^true'.
									
	self assert: (newMethod isMethod).
	self assert: (newMethod selector == #foo).
	self assert: (newMethod isMetaSide).
	self assert: (newMethod protocol = nil).
	
	self assert: (newMethod parent = newClass theMetaClass).
	self assert: (newMethod parentName = newClass theMetaClass name).
	
	self assert: (newMethod environment == Smalltalk globals).
	self assert: (newMethod realClass = OrderedCollection class).
	self assert: (newMethod compiledMethod isNil).! !

!RGMethodDefinitionTest methodsFor: 'testing' stamp: 'StephaneDucasse 8/12/2011 14:46'!
testSameMethodInSet
	"self debug: #testSameMethodInSet"

	| s rgmethod |
	s := Set new.
	rgmethod := (OrderedCollection>>#size) asRingDefinition.
	s add: rgmethod. 
	self assert: (s includes: rgmethod).
	
	s add: rgmethod. 
	self assert: (s size = 1).
	self assert: (s includes: rgmethod).
	
! !

TestCase subclass: #RGMonticelloTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Ring-Tests-Kernel'!

!RGMonticelloTest methodsFor: 'testing' stamp: 'VeronicaUquillas 7/18/2011 14:56'!
testConvertingMCClassDefinition
	| mcClass ringClass |
	
	mcClass := OrderedCollection asClassDefinition.
	ringClass := mcClass asRingDefinition.
	
	self assert: (ringClass isClass).
	self assert: (ringClass theMetaClass realClass = OrderedCollection class).
	self assert: (ringClass isSameRevisionAs: OrderedCollection asRingDefinition).
	self deny: (ringClass isSameRevisionAs: SortedCollection asRingDefinition)! !

!RGMonticelloTest methodsFor: 'testing' stamp: 'VeronicaUquillas 7/18/2011 14:50'!
testConvertingMCMethodDefinition
	| mcMethod ringMethod |
	
	mcMethod := (OrderedCollection >> #add: ) methodReference asMethodDefinition.
	ringMethod := mcMethod asRingDefinition.
	
	self assert: (ringMethod isMethod).
	self assert: (ringMethod isSameRevisionAs: ((OrderedCollection >> #add: ) asRingDefinition)).
	self deny: (ringMethod isSameRevisionAs: ((OrderedCollection >> #addAll: ) asRingDefinition))! !

!RGMonticelloTest methodsFor: 'testing' stamp: 'VeronicaUquillas 7/18/2011 14:45'!
testConvertingMCOrganizationDefinition
	| mcOrganization ringOrganization mcOrganization2 |
	
	mcOrganization := MCOrganizationDefinition categories: {#'Ring-Core-Kernel' . #'Ring-Core-Definitions'}.
	mcOrganization2 := MCOrganizationDefinition categories: {#'Ring-Core-Kernel' . #'Ring-Core-Definitions' . #'Ring-Core-Variables'}.
	ringOrganization := mcOrganization asRingDefinition.
	
	self assert: (ringOrganization isOrganization).
	self deny: (ringOrganization isSameRevisionAs: mcOrganization2 asRingDefinition)! !

!RGMonticelloTest methodsFor: 'testing' stamp: 'StephaneDucasse 7/19/2011 10:26'!
testConvertingMCTraitDefinition
	| mcClass ringClass |
	
	mcClass := TSortable asClassDefinition.
	ringClass := mcClass asRingDefinition.
	
	self assert: (ringClass isTrait).
	self assert: (ringClass theMetaClass realClass = TSortable class).
	self assert: (ringClass isSameRevisionAs: TSortable asRingDefinition).
	self deny: (ringClass isSameRevisionAs: TPureBehavior asRingDefinition)! !

TestCase subclass: #RGTraitDefinitionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Ring-Tests-Kernel'!

!RGTraitDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 16:45'!
testAddingMethods
	| newMethod newClass |
	
	newClass:= RGFactory current createTraitNamed: #TSortable.
	newMethod:= (RGFactory current createMethodNamed: #sort parent: newClass)
					protocol: 'sorting'; 
					sourceCode: 'sort
									self sort: [:a :b | a <= b]'.
	
	self assert: (newMethod isMetaSide not).
	self assert: (newClass hasMethods not).

	newClass addMethod: newMethod.
	newClass addSelector: #size 
			   classified: 'accessing' 
			   sourced: 'foo
							^lastIndex - firstIndex + 1'.
	
	self assert: (newClass hasMethods).
	self assert: (newClass selectors = #(sort size)).
	self assert: (newClass includesSelector: #sort).
	self assert: ((newClass methodNamed: #sort) = newMethod).
	self assert: (newClass methods size = 2).
	self assert: (newClass selectors size = 2).
	self assert: (newClass allSelectors size = 2).  "no hierarchy"

	newMethod:= newClass methodNamed: #size.
	self assert: (newMethod parent = newClass).
	
	self assert: ((newClass compiledMethodNamed: #sort) notNil).
	self assert: ((newClass compiledMethodNamed: #foo) isNil)! !

!RGTraitDefinitionTest methodsFor: 'testing' stamp: 'StephaneDucasse 7/19/2011 10:32'!
testAsTraitDefinition

	| newTrait |
	newTrait:= TPureBehavior asRingDefinition.
	self assert: (newTrait isRingObject).
	self assert: (newTrait isTrait).  
	self assert: (newTrait name == #TPureBehavior).  
	self assert: (newTrait category notNil).
	self assert: (newTrait superclassName notNil).
	
	
	self assert: (newTrait theMetaClass isRingObject).
	self assert: (newTrait theMetaClass isTrait).
	self assert: (newTrait theMetaClass traitCompositionSource = '{}').! !

!RGTraitDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 16:14'!
testExistingTrait
	| newClass metaClass |
	
	newClass:= RGFactory current createTraitNamed: #TSortable.
	self assert: (newClass isTrait).
	self assert: (newClass isDefined).
	self assert: (newClass realClass = TSortable).
	self assert: (newClass isMeta not).
	
	newClass withMetaclass.
	self assert: (newClass hasMetaclass).
	metaClass:= newClass theMetaClass.
	self assert: (metaClass isMeta).
	self assert: (metaClass name = 'TSortable classTrait').
	self assert: (metaClass theNonMetaClass = newClass).
	self assert: (metaClass realClass = TSortable class).! !

!RGTraitDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 16:14'!
testNonExistingClass
	| newClass |
	
	newClass:= RGFactory current createTraitNamed: #TConnection.
	self assert: (newClass isTrait).
	self assert: (newClass hasMetaclass not).
	self assert: (newClass hasComment not).
	self assert: (newClass hasStamp not).
	self assert: (newClass parent = Smalltalk globals).
	self assert: (newClass package isNil).
	self assert: (newClass category isNil).
	self assert: (newClass hasMethods not).
	self assert: (newClass hasSuperclass not).
	self assert: (newClass hasTraitComposition not).
	self assert: (newClass isDefined not).
	self assert: (newClass hasProtocols not).! !

!RGTraitDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 8/10/2011 11:42'!
testTraitEquality

	| newClass |
	self assert: TSortable asRingDefinition = TSortable asRingDefinition.
	
	newClass := (TSortable asRingDefinition)
		category: #Kernel.
	self assert: (TSortable asRingDefinition = newClass) ! !

TestCase subclass: #RGVariableDefinitionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Ring-Tests-Kernel'!

!RGVariableDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 16:19'!
testClassInstanceVariable
	| instVar newClass metaClass |
	
	instVar:= RGFactory current createClassInstanceVariableNamed:  'sizes'.
	
	self assert: (instVar isClassInstanceVariable).
	self assert: (instVar isVariable).
	self assert: (instVar name = 'sizes').
	self assert: (instVar parent isNil).
	self assert: (instVar isMetaSide).
	
	newClass:= RGFactory current createClassNamed: #OrderedCollection.
	newClass withMetaclass.
	metaClass:= newClass theMetaClass.
	instVar:= RGFactory current createClassInstanceVariableNamed: 'sizes' parent: metaClass.
	
	self assert: (instVar parent = metaClass).
	self assert: (metaClass instanceVariables isEmpty).
	
	metaClass instanceVariables add: instVar.
	self assert: (metaClass instanceVariables size = 1).! !

!RGVariableDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 16:20'!
testClassVariable
	| instVar newClass |
	
	instVar:= RGFactory current createClassVariableNamed: 'DependentsFields'.
	
	self assert: (instVar isClassVariable).
	self assert: (instVar isVariable).
	self assert: (instVar name = 'DependentsFields').
	self assert: (instVar parent isNil).
	self assert: (instVar isMetaSide not).   
	
	newClass:= RGFactory current createClassNamed: #Object.
	instVar:= RGFactory current createClassVariableNamed: 'DependentsFields' parent: newClass.
	
	self assert: (instVar parent = newClass).
	self assert: (newClass classVariables isEmpty).
	
	newClass classVariables add: instVar.
	self assert: (newClass classVariables size = 1).! !

!RGVariableDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 16:21'!
testInstanceVariable
	| instVar newClass |
	
	instVar:= RGFactory current createInstanceVariableNamed: 'size'.
	
	self assert: (instVar isInstanceVariable).
	self assert: (instVar isVariable).
	self assert: (instVar name = 'size').
	self assert: (instVar parent isNil).
	self assert: (instVar isMetaSide not).
	
	newClass:= RGFactory current createClassNamed: #OrderedCollection.
	instVar:= RGFactory current createInstanceVariableNamed: 'array' parent: newClass.
	
	self assert: (instVar parent = newClass).
	self assert: (newClass instanceVariables isEmpty).
	
	newClass instanceVariables add: instVar.
	self assert: (newClass instanceVariables size = 1).! !

!RGVariableDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 16:22'!
testPoolVariable
	| poolVar newClass |
	
	poolVar:= RGFactory current createPoolVariableNamed: 'TextConstants'.
	
	self assert: (poolVar isPoolVariable).
	self assert: (poolVar isVariable).
	self assert: (poolVar name = 'TextConstants').
	self assert: (poolVar parent isNil).
	self assert: (poolVar isMetaSide not).
	
	newClass:= RGFactory current createClassNamed: #OrderedCollection.
	poolVar:= RGFactory current createPoolVariableNamed: 'TextConstants' parent: newClass.
	
	self assert: (poolVar parent = newClass).
	self assert: (newClass poolDictionaries isEmpty).
	
	newClass poolDictionaries add: poolVar.
	self assert: (newClass poolDictionaries size = 1).! !

!RGVariableDefinitionTest methodsFor: 'testing' stamp: 'VeronicaUquillas 8/10/2011 11:42'!
testVariableEquality

	| variable1 variable2|
	
	variable1 := (OrderedCollection asRingDefinition) instVarNamed: #array.
	variable2 := (OrderedCollection asRingDefinition) instVarNamed: #array.
	self assert: variable1 = variable2.

	variable1 := (RGFactory current createClassVariableNamed: #Foo) parentName: #Test.
	variable2 := (RGFactory current createClassVariableNamed: #Foo) parentName: #Test.
	self assert: variable1 = variable2.
	
	variable2 := (RGFactory current createClassVariableNamed: #Foo) parentName: #Test2.
	self deny: variable1 = variable2.
	! !
